@@ -39,9 +39,25 @@ from .constants import (
 )
 from .api import MezonApi
 
+# Managers imports
+from .managers import (
+    ChannelManager,
+    SessionManager,
+    SocketManager,
+    CacheManager,
+    Collection,
+)
+
 # Import client
 from .client import MezonClient
 
+# Socket imports
+from .socket import WebSocketAdapter, WebSocketAdapterPb, Socket
+
+# Utils imports
+from .utils import setup_logger, get_logger, disable_logging, enable_logging
+
+
 __all__ = [
     # Version
     "__version__",
@@ -70,4 +86,18 @@ __all__ = [
     "ChannelType",
     "ChannelStreamMode",
     "TypeMessage",
+    # Socket
+    "WebSocketAdapter",
+    "WebSocketAdapterPb",
+    "Socket",
+    "ChannelManager",
+    "SessionManager",
+    "SocketManager",
+    "CacheManager",
+    "Collection",
+    # Utils
+    "setup_logger",
+    "get_logger",
+    "disable_logging",
+    "enable_logging",
 ]
