@@ -1,17 +1,11 @@
-"""
-Socket module for Mezon SDK
-"""
-
 from .websocket_adapter import (
     WebSocketAdapter,
-    WebSocketAdapterText,
     WebSocketAdapterPb,
 )
 from .default_socket import Socket
 
 __all__ = [
     "WebSocketAdapter",
-    "WebSocketAdapterText",
     "WebSocketAdapterPb",
     "Socket",
 ]
