@@ -10,6 +10,12 @@ from .helper import (
     parse_url_to_host_and_ssl,
     generate_snowflake_id,
 )
+from .logger import (
+    setup_logger,
+    get_logger,
+    disable_logging,
+    enable_logging,
+)
 
 __all__ = [
     "convert_internal_event_to_events",
@@ -18,4 +24,8 @@ __all__ = [
     "sleep",
     "parse_url_to_host_and_ssl",
     "generate_snowflake_id",
+    "setup_logger",
+    "get_logger",
+    "disable_logging",
+    "enable_logging",
 ]
